# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/extraction_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ommon/extraction_objects.proto\x12\x12\x65xtraction_objects\"\x82\x01\n\x08\x42ookmark\x12\x42\n\x0b\x63heckpoints\x18\x01 \x03(\x0b\x32-.extraction_objects.Bookmark.CheckpointsEntry\x1a\x32\n\x10\x43heckpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x01\n\x1d\x45xtractionProgressDetailGroup\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12O\n\x07\x64\x65tails\x18\x03 \x03(\x0b\x32>.extraction_objects.ExtractionProgressDetailGroup.DetailsEntry\x1a.\n\x0c\x44\x65tailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"8\n\x18\x45xtractionProgressDetail\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\xd8\x01\n\x12\x45xtractionProgress\x12\x11\n\x07message\x18\x01 \x01(\tH\x00\x12J\n\x12\x65xtraction_message\x18\x02 \x01(\x0b\x32,.extraction_objects.ExtractionProgressDetailH\x00\x12M\n\x10progress_details\x18\x03 \x01(\x0b\x32\x31.extraction_objects.ExtractionProgressDetailGroupH\x00\x42\x14\n\x12\x45xtractionProgress\"\x87\x01\n\rKeyedBookmark\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x03(\x0b\x32,.extraction_objects.KeyedBookmark.ValueEntry\x1a,\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42L\n\"alation.sdk.grpc.common.extractionB\x11\x45xtractionObjectsP\x01Z\x11\x63ommon/extractionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.extraction_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"alation.sdk.grpc.common.extractionB\021ExtractionObjectsP\001Z\021common/extraction'
  _globals['_BOOKMARK_CHECKPOINTSENTRY']._options = None
  _globals['_BOOKMARK_CHECKPOINTSENTRY']._serialized_options = b'8\001'
  _globals['_EXTRACTIONPROGRESSDETAILGROUP_DETAILSENTRY']._options = None
  _globals['_EXTRACTIONPROGRESSDETAILGROUP_DETAILSENTRY']._serialized_options = b'8\001'
  _globals['_KEYEDBOOKMARK_VALUEENTRY']._options = None
  _globals['_KEYEDBOOKMARK_VALUEENTRY']._serialized_options = b'8\001'
  _globals['_BOOKMARK']._serialized_start=56
  _globals['_BOOKMARK']._serialized_end=186
  _globals['_BOOKMARK_CHECKPOINTSENTRY']._serialized_start=136
  _globals['_BOOKMARK_CHECKPOINTSENTRY']._serialized_end=186
  _globals['_EXTRACTIONPROGRESSDETAILGROUP']._serialized_start=189
  _globals['_EXTRACTIONPROGRESSDETAILGROUP']._serialized_end=379
  _globals['_EXTRACTIONPROGRESSDETAILGROUP_DETAILSENTRY']._serialized_start=333
  _globals['_EXTRACTIONPROGRESSDETAILGROUP_DETAILSENTRY']._serialized_end=379
  _globals['_EXTRACTIONPROGRESSDETAIL']._serialized_start=381
  _globals['_EXTRACTIONPROGRESSDETAIL']._serialized_end=437
  _globals['_EXTRACTIONPROGRESS']._serialized_start=440
  _globals['_EXTRACTIONPROGRESS']._serialized_end=656
  _globals['_KEYEDBOOKMARK']._serialized_start=659
  _globals['_KEYEDBOOKMARK']._serialized_end=794
  _globals['_KEYEDBOOKMARK_VALUEENTRY']._serialized_start=750
  _globals['_KEYEDBOOKMARK_VALUEENTRY']._serialized_end=794
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.common import auth_pb2 as _auth_pb2
from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as _mde_objects_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TableProfilingRequest(_message.Message):
    __slots__ = ("configuration", "tableRequests", "auth", "jdbcUri")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    TABLEREQUESTS_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    JDBCURI_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    tableRequests: _containers.RepeatedCompositeFieldContainer[TableRequest]
    auth: _auth_pb2.Auth
    jdbcUri: str
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., tableRequests: _Optional[_Iterable[_Union[TableRequest, _Mapping]]] = ..., auth: _Optional[_Union[_auth_pb2.Auth, _Mapping]] = ..., jdbcUri: _Optional[str] = ...) -> None: ...

class TableRequest(_message.Message):
    __slots__ = ("id", "name", "schema", "populationSize", "sampleSize", "sensitiveColumns", "columns", "timeout", "schema_name", "catalog_name")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    POPULATIONSIZE_FIELD_NUMBER: _ClassVar[int]
    SAMPLESIZE_FIELD_NUMBER: _ClassVar[int]
    SENSITIVECOLUMNS_FIELD_NUMBER: _ClassVar[int]
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_NAME_FIELD_NUMBER: _ClassVar[int]
    CATALOG_NAME_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    schema: str
    populationSize: int
    sampleSize: int
    sensitiveColumns: _containers.RepeatedCompositeFieldContainer[Column]
    columns: _containers.RepeatedCompositeFieldContainer[Column]
    timeout: int
    schema_name: str
    catalog_name: str
    def __init__(self, id: _Optional[int] = ..., name: _Optional[str] = ..., schema: _Optional[str] = ..., populationSize: _Optional[int] = ..., sampleSize: _Optional[int] = ..., sensitiveColumns: _Optional[_Iterable[_Union[Column, _Mapping]]] = ..., columns: _Optional[_Iterable[_Union[Column, _Mapping]]] = ..., timeout: _Optional[int] = ..., schema_name: _Optional[str] = ..., catalog_name: _Optional[str] = ...) -> None: ...

class Column(_message.Message):
    __slots__ = ("name", "id", "columnType")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    COLUMNTYPE_FIELD_NUMBER: _ClassVar[int]
    name: str
    id: int
    columnType: _mde_objects_pb2.ColumnType
    def __init__(self, name: _Optional[str] = ..., id: _Optional[int] = ..., columnType: _Optional[_Union[_mde_objects_pb2.ColumnType, _Mapping]] = ...) -> None: ...

class TableProfilingResponse(_message.Message):
    __slots__ = ("id", "rowSamples", "numberOfRowsSampled", "secondsTaken", "hasMore", "columnSummaries")
    ID_FIELD_NUMBER: _ClassVar[int]
    ROWSAMPLES_FIELD_NUMBER: _ClassVar[int]
    NUMBEROFROWSSAMPLED_FIELD_NUMBER: _ClassVar[int]
    SECONDSTAKEN_FIELD_NUMBER: _ClassVar[int]
    HASMORE_FIELD_NUMBER: _ClassVar[int]
    COLUMNSUMMARIES_FIELD_NUMBER: _ClassVar[int]
    id: int
    rowSamples: _containers.RepeatedCompositeFieldContainer[Row]
    numberOfRowsSampled: int
    secondsTaken: int
    hasMore: bool
    columnSummaries: _containers.RepeatedCompositeFieldContainer[ColumnSummary]
    def __init__(self, id: _Optional[int] = ..., rowSamples: _Optional[_Iterable[_Union[Row, _Mapping]]] = ..., numberOfRowsSampled: _Optional[int] = ..., secondsTaken: _Optional[int] = ..., hasMore: bool = ..., columnSummaries: _Optional[_Iterable[_Union[ColumnSummary, _Mapping]]] = ...) -> None: ...

class Row(_message.Message):
    __slots__ = ("values",)
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, values: _Optional[_Iterable[str]] = ...) -> None: ...

class ColumnSummary(_message.Message):
    __slots__ = ("distribution", "numberOfNulls", "numberOfUniqueValues", "numberOfAllValues", "column")
    DISTRIBUTION_FIELD_NUMBER: _ClassVar[int]
    NUMBEROFNULLS_FIELD_NUMBER: _ClassVar[int]
    NUMBEROFUNIQUEVALUES_FIELD_NUMBER: _ClassVar[int]
    NUMBEROFALLVALUES_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    distribution: _containers.RepeatedCompositeFieldContainer[ColumnDistribution]
    numberOfNulls: int
    numberOfUniqueValues: int
    numberOfAllValues: int
    column: Column
    def __init__(self, distribution: _Optional[_Iterable[_Union[ColumnDistribution, _Mapping]]] = ..., numberOfNulls: _Optional[int] = ..., numberOfUniqueValues: _Optional[int] = ..., numberOfAllValues: _Optional[int] = ..., column: _Optional[_Union[Column, _Mapping]] = ...) -> None: ...

class ColumnDistribution(_message.Message):
    __slots__ = ("value", "count")
    VALUE_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    value: str
    count: int
    def __init__(self, value: _Optional[str] = ..., count: _Optional[int] = ...) -> None: ...

class CustomTableProfilingRequest(_message.Message):
    __slots__ = ("configuration", "tableRequests", "auth", "jdbcUri")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    TABLEREQUESTS_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    JDBCURI_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    tableRequests: _containers.RepeatedCompositeFieldContainer[CustomTableRequest]
    auth: _auth_pb2.Auth
    jdbcUri: str
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., tableRequests: _Optional[_Iterable[_Union[CustomTableRequest, _Mapping]]] = ..., auth: _Optional[_Union[_auth_pb2.Auth, _Mapping]] = ..., jdbcUri: _Optional[str] = ...) -> None: ...

class CustomTableRequest(_message.Message):
    __slots__ = ("request", "override")
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    request: TableRequest
    override: str
    def __init__(self, request: _Optional[_Union[TableRequest, _Mapping]] = ..., override: _Optional[str] = ...) -> None: ...

class CustomTableProfilingResponse(_message.Message):
    __slots__ = ("response", "schema")
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    response: TableProfilingResponse
    schema: _containers.RepeatedCompositeFieldContainer[Column]
    def __init__(self, response: _Optional[_Union[TableProfilingResponse, _Mapping]] = ..., schema: _Optional[_Iterable[_Union[Column, _Mapping]]] = ...) -> None: ...

class ColumnProfilingRequest(_message.Message):
    __slots__ = ("configuration", "request", "auth", "jdbcUri")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    JDBCURI_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    request: ColumnRequest
    auth: _auth_pb2.Auth
    jdbcUri: str
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., request: _Optional[_Union[ColumnRequest, _Mapping]] = ..., auth: _Optional[_Union[_auth_pb2.Auth, _Mapping]] = ..., jdbcUri: _Optional[str] = ...) -> None: ...

class ColumnRequest(_message.Message):
    __slots__ = ("schema", "table", "column", "sampleSize", "timeout", "type", "schema_name", "catalog_name")
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    SAMPLESIZE_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_NAME_FIELD_NUMBER: _ClassVar[int]
    CATALOG_NAME_FIELD_NUMBER: _ClassVar[int]
    schema: str
    table: str
    column: str
    sampleSize: int
    timeout: int
    type: _mde_objects_pb2.ColumnType.NormalizedType
    schema_name: str
    catalog_name: str
    def __init__(self, schema: _Optional[str] = ..., table: _Optional[str] = ..., column: _Optional[str] = ..., sampleSize: _Optional[int] = ..., timeout: _Optional[int] = ..., type: _Optional[_Union[_mde_objects_pb2.ColumnType.NormalizedType, str]] = ..., schema_name: _Optional[str] = ..., catalog_name: _Optional[str] = ...) -> None: ...

class ColumnProfilingResponse(_message.Message):
    __slots__ = ("distribution", "final")
    DISTRIBUTION_FIELD_NUMBER: _ClassVar[int]
    FINAL_FIELD_NUMBER: _ClassVar[int]
    distribution: ColumnDistribution
    final: ColumnProfilingFinalResponse
    def __init__(self, distribution: _Optional[_Union[ColumnDistribution, _Mapping]] = ..., final: _Optional[_Union[ColumnProfilingFinalResponse, _Mapping]] = ...) -> None: ...

class ColumnProfilingFinalResponse(_message.Message):
    __slots__ = ("statistics", "hasMore", "secondsTaken")
    STATISTICS_FIELD_NUMBER: _ClassVar[int]
    HASMORE_FIELD_NUMBER: _ClassVar[int]
    SECONDSTAKEN_FIELD_NUMBER: _ClassVar[int]
    statistics: _containers.RepeatedCompositeFieldContainer[Statistic]
    hasMore: bool
    secondsTaken: int
    def __init__(self, statistics: _Optional[_Iterable[_Union[Statistic, _Mapping]]] = ..., hasMore: bool = ..., secondsTaken: _Optional[int] = ...) -> None: ...

class Statistic(_message.Message):
    __slots__ = ("name", "value")
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: str
    def __init__(self, name: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class CustomColumnProfilingRequest(_message.Message):
    __slots__ = ("configuration", "request", "override", "auth", "jdbcUri")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    JDBCURI_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    request: ColumnRequest
    override: ColumnStatisticsOverride
    auth: _auth_pb2.Auth
    jdbcUri: str
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., request: _Optional[_Union[ColumnRequest, _Mapping]] = ..., override: _Optional[_Union[ColumnStatisticsOverride, _Mapping]] = ..., auth: _Optional[_Union[_auth_pb2.Auth, _Mapping]] = ..., jdbcUri: _Optional[str] = ...) -> None: ...

class ColumnStatisticsOverride(_message.Message):
    __slots__ = ("literal", "templated")
    LITERAL_FIELD_NUMBER: _ClassVar[int]
    TEMPLATED_FIELD_NUMBER: _ClassVar[int]
    literal: str
    templated: TemplatedColumnStatisticsOverride
    def __init__(self, literal: _Optional[str] = ..., templated: _Optional[_Union[TemplatedColumnStatisticsOverride, _Mapping]] = ...) -> None: ...

class TemplatedColumnStatisticsOverride(_message.Message):
    __slots__ = ("numericTemplate", "nonNumericTemplate", "columnPlaceholder", "tablePlaceholder", "limitPlaceholder")
    NUMERICTEMPLATE_FIELD_NUMBER: _ClassVar[int]
    NONNUMERICTEMPLATE_FIELD_NUMBER: _ClassVar[int]
    COLUMNPLACEHOLDER_FIELD_NUMBER: _ClassVar[int]
    TABLEPLACEHOLDER_FIELD_NUMBER: _ClassVar[int]
    LIMITPLACEHOLDER_FIELD_NUMBER: _ClassVar[int]
    numericTemplate: str
    nonNumericTemplate: str
    columnPlaceholder: str
    tablePlaceholder: str
    limitPlaceholder: str
    def __init__(self, numericTemplate: _Optional[str] = ..., nonNumericTemplate: _Optional[str] = ..., columnPlaceholder: _Optional[str] = ..., tablePlaceholder: _Optional[str] = ..., limitPlaceholder: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from policy import policy_sync_pb2 as policy_dot_policy__sync__pb2


class RdbmsPolicySyncStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PolicySyncApply = channel.unary_stream(
                '/ocf.policy.rdbms.RdbmsPolicySync/PolicySyncApply',
                request_serializer=policy_dot_policy__sync__pb2.PolicySyncRequest.SerializeToString,
                response_deserializer=policy_dot_policy__sync__pb2.PolicySyncResponse.FromString,
                )
        self.PolicySyncRevoke = channel.unary_stream(
                '/ocf.policy.rdbms.RdbmsPolicySync/PolicySyncRevoke',
                request_serializer=policy_dot_policy__sync__pb2.PolicySyncRequest.SerializeToString,
                response_deserializer=policy_dot_policy__sync__pb2.PolicySyncResponse.FromString,
                )


class RdbmsPolicySyncServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PolicySyncApply(self, request, context):
        """Apply a policy to a list of objects.
        The response is the list of links that were created
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PolicySyncRevoke(self, request, context):
        """Revoke a policy from a list of objects.
        The response is the list of links that were deleted
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RdbmsPolicySyncServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'PolicySyncApply': grpc.unary_stream_rpc_method_handler(
                    servicer.PolicySyncApply,
                    request_deserializer=policy_dot_policy__sync__pb2.PolicySyncRequest.FromString,
                    response_serializer=policy_dot_policy__sync__pb2.PolicySyncResponse.SerializeToString,
            ),
            'PolicySyncRevoke': grpc.unary_stream_rpc_method_handler(
                    servicer.PolicySyncRevoke,
                    request_deserializer=policy_dot_policy__sync__pb2.PolicySyncRequest.FromString,
                    response_serializer=policy_dot_policy__sync__pb2.PolicySyncResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ocf.policy.rdbms.RdbmsPolicySync', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RdbmsPolicySync(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PolicySyncApply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ocf.policy.rdbms.RdbmsPolicySync/PolicySyncApply',
            policy_dot_policy__sync__pb2.PolicySyncRequest.SerializeToString,
            policy_dot_policy__sync__pb2.PolicySyncResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PolicySyncRevoke(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ocf.policy.rdbms.RdbmsPolicySync/PolicySyncRevoke',
            policy_dot_policy__sync__pb2.PolicySyncRequest.SerializeToString,
            policy_dot_policy__sync__pb2.PolicySyncResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Request(_message.Message):
    __slots__ = ("configuration", "runConfiguration")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    RUNCONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    runConfiguration: RunConfiguration
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., runConfiguration: _Optional[_Union[RunConfiguration, _Mapping]] = ...) -> None: ...

class RunConfiguration(_message.Message):
    __slots__ = ("limit", "startTime", "endTime")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    STARTTIME_FIELD_NUMBER: _ClassVar[int]
    ENDTIME_FIELD_NUMBER: _ClassVar[int]
    limit: int
    startTime: _timestamp_pb2.Timestamp
    endTime: _timestamp_pb2.Timestamp
    def __init__(self, limit: _Optional[int] = ..., startTime: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., endTime: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Response(_message.Message):
    __slots__ = ("statement", "result", "isResult")
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    ISRESULT_FIELD_NUMBER: _ClassVar[int]
    statement: QueryStatement
    result: FinalResult
    isResult: bool
    def __init__(self, statement: _Optional[_Union[QueryStatement, _Mapping]] = ..., result: _Optional[_Union[FinalResult, _Mapping]] = ..., isResult: bool = ...) -> None: ...

class FinalResult(_message.Message):
    __slots__ = ("statementCount", "accounts", "warnings")
    class AccountsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    STATEMENTCOUNT_FIELD_NUMBER: _ClassVar[int]
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    WARNINGS_FIELD_NUMBER: _ClassVar[int]
    statementCount: int
    accounts: _containers.ScalarMap[str, int]
    warnings: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, statementCount: _Optional[int] = ..., accounts: _Optional[_Mapping[str, int]] = ..., warnings: _Optional[_Iterable[str]] = ...) -> None: ...

class QueryStatement(_message.Message):
    __slots__ = ("userName", "text", "defaultDatabases", "sessionId", "sessionStartTime", "startTime", "cancelled", "secondsTaken", "destinationTable")
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    DEFAULTDATABASES_FIELD_NUMBER: _ClassVar[int]
    SESSIONID_FIELD_NUMBER: _ClassVar[int]
    SESSIONSTARTTIME_FIELD_NUMBER: _ClassVar[int]
    STARTTIME_FIELD_NUMBER: _ClassVar[int]
    CANCELLED_FIELD_NUMBER: _ClassVar[int]
    SECONDSTAKEN_FIELD_NUMBER: _ClassVar[int]
    DESTINATIONTABLE_FIELD_NUMBER: _ClassVar[int]
    userName: str
    text: str
    defaultDatabases: str
    sessionId: str
    sessionStartTime: _timestamp_pb2.Timestamp
    startTime: _timestamp_pb2.Timestamp
    cancelled: bool
    secondsTaken: float
    destinationTable: str
    def __init__(self, userName: _Optional[str] = ..., text: _Optional[str] = ..., defaultDatabases: _Optional[str] = ..., sessionId: _Optional[str] = ..., sessionStartTime: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., startTime: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., cancelled: bool = ..., secondsTaken: _Optional[float] = ..., destinationTable: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Agent(_message.Message):
    __slots__ = ("uuid",)
    UUID_FIELD_NUMBER: _ClassVar[int]
    uuid: str
    def __init__(self, uuid: _Optional[str] = ...) -> None: ...

class ProxyList(_message.Message):
    __slots__ = ("proxies",)
    PROXIES_FIELD_NUMBER: _ClassVar[int]
    proxies: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, proxies: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fs/mde.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from fs import mde_objects_pb2 as fs_dot_mde__objects__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x66s/mde.proto\x12\x06\x66s.mde\x1a\x1a\x63ommon/configuration.proto\x1a\x14\x66s/mde_objects.proto\x1a\x16\x63ommon/job_error.proto\"O\n\x17\x46ilterExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\">\n\x18\x46ilterExtractionResponse\x12\"\n\x04path\x18\x01 \x01(\x0b\x32\x14.fs.mde_objects.Path\"\xc0\x01\n\x19MetadataExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12*\n\x08\x62ookmark\x18\x02 \x03(\x0b\x32\x18.fs.mde_objects.Bookmark\x12&\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x16.fs.mde_objects.Filter\x12\x19\n\x11is_include_filter\x18\x04 \x01(\x08\"\xf0\x01\n\x1aMetadataExtractionResponse\x12$\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x14.fs.mde_objects.FileH\x00\x12,\n\x08\x62ookmark\x18\x02 \x01(\x0b\x32\x18.fs.mde_objects.BookmarkH\x00\x12@\n\x12\x65xtractionProgress\x18\x03 \x01(\x0b\x32\".fs.mde_objects.ExtractionProgressH\x00\x12!\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x19\n\x17\x45xtractMetadataResponse\"\xf3\x01\n\x18\x43olumnExtractionResponse\x12(\n\x06\x63olumn\x18\x01 \x01(\x0b\x32\x16.fs.mde_objects.ColumnH\x00\x12,\n\x08\x62ookmark\x18\x02 \x01(\x0b\x32\x18.fs.mde_objects.BookmarkH\x00\x12@\n\x12\x65xtractionProgress\x18\x03 \x01(\x0b\x32\".fs.mde_objects.ExtractionProgressH\x00\x12!\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x1a\n\x18\x43olumnExtractionResponseB7\n\x17\x61lation.sdk.fs.grpc.mdeB\x12MetadataExtractionP\x01Z\x06\x66s/mdeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fs.mde_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.fs.grpc.mdeB\022MetadataExtractionP\001Z\006fs/mde'
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_start=98
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_end=177
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_start=179
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_end=241
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_start=244
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_end=436
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_start=439
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_end=679
  _globals['_COLUMNEXTRACTIONRESPONSE']._serialized_start=682
  _globals['_COLUMNEXTRACTIONRESPONSE']._serialized_end=925
# @@protoc_insertion_point(module_scope)



import unittest
from unittest.mock import Mock, patch
import os
from .queryclient import QueryClient


class TestQueryClient(unittest.TestCase):
    
    def test_default_max_inbound_message_size(self):
        """Test that the default max inbound message size is set correctly"""
        expected_size = 1024 * 1024 * 64  # 64MiB
        self.assertEqual(QueryClient.DEFAULT_MAX_INBOUND_IN_BYTES, expected_size)
    
    def test_init(self):
        """Test QueryClient initialization"""
        mock_channel = Mock()
        client = QueryClient(mock_channel)
        
        self.assertEqual(client.channel, mock_channel)
        self.assertIsNotNone(client.inner)
    
    @patch.dict(os.environ, {'CONNECTOR_HOST': 'test-host'})
    def test_from_connector_id_with_env_var(self):
        """Test from_connector_id with CONNECTOR_HOST environment variable"""
        with patch.object(QueryClient, 'from_target') as mock_from_target:
            mock_client = Mock()
            mock_from_target.return_value = mock_client
            
            result = QueryClient.from_connector_id(123)
            
            expected_target = "test-host:10123"
            mock_from_target.assert_called_once_with(
                expected_target, QueryClient.DEFAULT_MAX_INBOUND_IN_BYTES
            )
            self.assertEqual(result, mock_client)
    
    @patch.dict(os.environ, {}, clear=True)
    def test_from_connector_id_without_env_var(self):
        """Test from_connector_id without CONNECTOR_HOST environment variable"""
        with patch.object(QueryClient, 'from_target') as mock_from_target:
            mock_client = Mock()
            mock_from_target.return_value = mock_client
            
            result = QueryClient.from_connector_id(456)
            
            expected_target = "localhost:10456"
            mock_from_target.assert_called_once_with(
                expected_target, QueryClient.DEFAULT_MAX_INBOUND_IN_BYTES
            )
            self.assertEqual(result, mock_client)
    
    def test_from_connector_id_with_custom_message_size(self):
        """Test from_connector_id with custom max_inbound_message_size"""
        custom_size = 1024 * 1024 * 128  # 128MiB
        
        with patch.object(QueryClient, 'from_target') as mock_from_target:
            mock_client = Mock()
            mock_from_target.return_value = mock_client
            
            result = QueryClient.from_connector_id(789, custom_size)
            
            expected_target = "localhost:10789"
            mock_from_target.assert_called_once_with(expected_target, custom_size)
            self.assertEqual(result, mock_client)
    
    def test_from_target(self):
        """Test from_target class method"""
        with patch.object(QueryClient, 'resolve') as mock_resolve:
            mock_channel = Mock()
            mock_resolve.return_value = mock_channel
            
            result = QueryClient.from_target("test-target:8080", 1024)
            
            mock_resolve.assert_called_once_with(
                target="test-target:8080", max_inbound_message_size=1024
            )
            self.assertIsInstance(result, QueryClient)
            self.assertEqual(result.channel, mock_channel)
    
    
    @patch.object(QueryClient, 'configuration_from_b64_string')
    def test_new_session_from_b64_config_only(self, mock_config_from_b64):
        """Test new_session_from_b64 with configuration only"""
        mock_channel = Mock()
        mock_config = Mock()
        
        client = QueryClient(mock_channel)
        
        # Mock configuration_from_b64_string to return a mock config
        mock_config_from_b64.return_value = mock_config
        
        # Mock new_session
        mock_session = Mock()
        client.new_session = Mock(return_value=mock_session)
        
        # Use any base64 string (we're mocking the decode anyway)
        result = client.new_session_from_b64("encoded_config")
        
        # Check that configuration_from_b64_string was called
        mock_config_from_b64.assert_called_once_with("encoded_config")
        
        # Verify new_session was called with config and None auth
        client.new_session.assert_called_once_with(mock_config, None)
        self.assertEqual(result, mock_session)
    
    @patch.object(QueryClient, 'auth_configuration_from_b64_string')
    @patch.object(QueryClient, 'configuration_from_b64_string')
    def test_new_session_from_b64_with_auth(self, mock_config_from_b64, mock_auth_from_b64):
        """Test new_session_from_b64 with configuration and authentication"""
        mock_channel = Mock()
        mock_config = Mock()
        mock_auth_obj = Mock()
        
        client = QueryClient(mock_channel)
        
        # Mock the static methods
        mock_config_from_b64.return_value = mock_config
        mock_auth_from_b64.return_value = mock_auth_obj
        
        # Mock new_session
        mock_session = Mock()
        client.new_session = Mock(return_value=mock_session)
        
        result = client.new_session_from_b64("encoded_config", "encoded_auth")
        
        # Check that both static methods were called
        mock_config_from_b64.assert_called_once_with("encoded_config")
        mock_auth_from_b64.assert_called_once_with("encoded_auth")
        
        # Verify new_session was called with both config and auth
        client.new_session.assert_called_once_with(mock_config, mock_auth_obj)
        self.assertEqual(result, mock_session)


if __name__ == '__main__':
    unittest.main()


from queryservice_client.stream.segments.column import Column

class Metadata:
    def __init__(self):
        self.by_ordinality = {}
        self.by_name = {}

    def get_columns(self):
        return sorted(self.by_ordinality.values(), key=lambda col: col.ordinality)
    
    def get_columns_name(self):
        return [name for name in self.by_name.keys()]

    def get_index(self, index):
        return self.by_ordinality.get(index)

    def get_name(self, name):
        return self.by_name.get(name)

    def add(self, projection):
        self.add_column(Column.from_projection(projection))
        return self

    def add_column(self, column):
        self.by_ordinality[column.ordinality] = column
        self.by_name[column.name] = column
        return self

    def size(self):
        return len(self.by_ordinality)

    def __eq__(self, other):
        if isinstance(other, Metadata):
            return self.by_ordinality == other.by_ordinality and self.by_name == other.by_name
        return False

    def __hash__(self):
        return hash((frozenset(self.by_ordinality.items()), frozenset(self.by_name.items())))


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/datasource.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63ommon/datasource.proto\x12\ndatasource\"9\n\x0e\x43onnectionInfo\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\"\x06\n\x04Self\"\xa6\x01\n\nDataSource\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.datasource.SourceType\x12 \n\x04self\x18\x14 \x01(\x0b\x32\x10.datasource.SelfH\x00\x12\x0c\n\x02id\x18\x15 \x01(\x05H\x00\x12\x30\n\nconnection\x18\x16 \x01(\x0b\x32\x1a.datasource.ConnectionInfoH\x00\x42\x10\n\x0eresolutionInfo*1\n\nSourceType\x12\x08\n\x04None\x10\x00\x12\t\n\x05RDBMS\x10\x01\x12\x06\n\x02\x42I\x10\x02\x12\x06\n\x02\x46S\x10\x03\x42\x46\n\"alation.sdk.grpc.common.datasourceB\x0b\x44\x61taSourcesP\x01Z\x11\x63ommon/datasourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.datasource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"alation.sdk.grpc.common.datasourceB\013DataSourcesP\001Z\021common/datasource'
  _globals['_SOURCETYPE']._serialized_start=275
  _globals['_SOURCETYPE']._serialized_end=324
  _globals['_CONNECTIONINFO']._serialized_start=39
  _globals['_CONNECTIONINFO']._serialized_end=96
  _globals['_SELF']._serialized_start=98
  _globals['_SELF']._serialized_end=104
  _globals['_DATASOURCE']._serialized_start=107
  _globals['_DATASOURCE']._serialized_end=273
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.common import checks_pb2 as _checks_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fs/mde_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x66s/mde_objects.proto\x12\x0e\x66s.mde_objects\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x18\n\x04Path\x12\x10\n\x08\x66ilePath\x18\x01 \x01(\t\"n\n\x12\x45xtractionProgress\x12\x11\n\x07message\x18\x01 \x01(\tH\x00\x12/\n\x0e\x63ompletedOtype\x18\x02 \x01(\x0e\x32\x15.fs.mde_objects.OtypeH\x00\x42\x14\n\x12\x45xtractionProgress\",\n\x06\x46ilter\x12\"\n\x04path\x18\x01 \x03(\x0b\x32\x14.fs.mde_objects.Path\"\xe0\x02\n\x04\x46ile\x12\x10\n\x08rootPath\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x03(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x15\n\rpathDelimiter\x18\x04 \x01(\t\x12\x13\n\x0bisDirectory\x18\x05 \x01(\x08\x12\x11\n\tisDeleted\x18\x06 \x01(\x08\x12\r\n\x05owner\x18\x07 \x01(\t\x12\x13\n\x0bsizeInBytes\x18\x08 \x01(\x04\x12.\n\ncreateTime\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15lastModifiedTimestamp\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15lastAccessedTimestamp\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05group\x18\x0c \x01(\t\x12\x12\n\npermission\x18\r \x01(\t\"?\n\x08\x42ookmark\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\";\n\x08\x43olumnId\x12\x0c\n\x04path\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bisDirectory\x18\x03 \x01(\x08\"\xd4\x01\n\nColumnType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07remarks\x18\x02 \x01(\t\x12=\n\nnormalized\x18\x03 \x01(\x0e\x32).fs.mde_objects.ColumnType.NormalizedType\"h\n\x0eNormalizedType\x12\t\n\x05OTHER\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\x08\n\x04\x44\x41TE\x10\x02\x12\x07\n\x03INT\x10\x03\x12\t\n\x05\x46LOAT\x10\x04\x12\n\n\x06STRING\x10\x05\x12\x08\n\x04TIME\x10\x06\x12\r\n\tTIMESTAMP\x10\x07\"~\n\x06\x43olumn\x12$\n\x02id\x18\x01 \x01(\x0b\x32\x18.fs.mde_objects.ColumnId\x12(\n\x04type\x18\x02 \x01(\x0b\x32\x1a.fs.mde_objects.ColumnType\x12\x10\n\x08position\x18\x03 \x01(\x05\x12\x12\n\nisNullable\x18\x04 \x01(\x08*+\n\x05Otype\x12\x08\n\x04\x46ILE\x10\x00\x12\x0c\n\x08\x42OOKMARK\x10\x01\x12\n\n\x06\x43OLUMN\x10\x02\x42<\n\x17\x61lation.sdk.fs.grpc.mdeB\x0fMetadataObjectsP\x01Z\x0e\x66s/mde_objectsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fs.mde_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.fs.grpc.mdeB\017MetadataObjectsP\001Z\016fs/mde_objects'
  _globals['_OTYPE']._serialized_start=1111
  _globals['_OTYPE']._serialized_end=1154
  _globals['_PATH']._serialized_start=103
  _globals['_PATH']._serialized_end=127
  _globals['_EXTRACTIONPROGRESS']._serialized_start=129
  _globals['_EXTRACTIONPROGRESS']._serialized_end=239
  _globals['_FILTER']._serialized_start=241
  _globals['_FILTER']._serialized_end=285
  _globals['_FILE']._serialized_start=288
  _globals['_FILE']._serialized_end=640
  _globals['_BOOKMARK']._serialized_start=642
  _globals['_BOOKMARK']._serialized_end=705
  _globals['_COLUMNID']._serialized_start=707
  _globals['_COLUMNID']._serialized_end=766
  _globals['_COLUMNTYPE']._serialized_start=769
  _globals['_COLUMNTYPE']._serialized_end=981
  _globals['_COLUMNTYPE_NORMALIZEDTYPE']._serialized_start=877
  _globals['_COLUMNTYPE_NORMALIZEDTYPE']._serialized_end=981
  _globals['_COLUMN']._serialized_start=983
  _globals['_COLUMN']._serialized_end=1109
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cf/cf_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63\x66/cf_objects.proto\x12\x11ocf.cf.cf_objects\x1a\x17rdbms/mde_objects.proto\"\x1e\n\rCustomFieldId\x12\r\n\x05parts\x18\x01 \x03(\t\"y\n\x10\x43ustomFieldApiId\x12\x39\n\x03key\x18\x01 \x03(\x0b\x32,.ocf.cf.cf_objects.CustomFieldApiId.KeyEntry\x1a*\n\x08KeyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf3\x01\n\x0b\x43ustomField\x12,\n\x02id\x18\x01 \x01(\x0b\x32 .ocf.cf.cf_objects.CustomFieldId\x12\x32\n\x05\x61piId\x18\x02 \x01(\x0b\x32#.ocf.cf.cf_objects.CustomFieldApiId\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1a\n\x12\x66ullyQualifiedName\x18\x04 \x01(\t\x12;\n\x0f\x63ustomFieldType\x18\x05 \x01(\x0e\x32\".ocf.cf.cf_objects.CustomFieldType\x12\x1b\n\x13\x61llowedPickerValues\x18\x06 \x03(\t\"`\n\x16\x43ustomFieldPickerValue\x12\x37\n\rcustomFieldId\x18\x01 \x01(\x0b\x32 .ocf.cf.cf_objects.CustomFieldId\x12\r\n\x05value\x18\x02 \x01(\t\"\xf4\x01\n\x0f\x43ustomFieldLink\x12/\n\x08schemaId\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaIdH\x00\x12-\n\x07tableId\x18\x02 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableIdH\x00\x12/\n\x08\x63olumnId\x18\x03 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnIdH\x00\x12@\n\x0bpickerValue\x18\x04 \x01(\x0b\x32).ocf.cf.cf_objects.CustomFieldPickerValueH\x01\x42\x05\n\x03oidB\x07\n\x05value\"2\n\x14\x43ustomFieldSyncValue\x12\x11\n\x07vString\x18\x01 \x01(\tH\x00\x42\x07\n\x05value\"\x81\x03\n\x16\x43ustomFieldValueUpdate\x12\x35\n\x0bschemaApiId\x18\x01 \x01(\x0b\x32\x1e.rdbms.mde_objects.SchemaApiIdH\x00\x12\x33\n\ntableApiId\x18\x02 \x01(\x0b\x32\x1d.rdbms.mde_objects.TableApiIdH\x00\x12\x35\n\x0b\x63olumnApiId\x18\x03 \x01(\x0b\x32\x1e.rdbms.mde_objects.ColumnApiIdH\x00\x12=\n\x10\x63ustomFieldApiId\x18\x04 \x01(\x0b\x32#.ocf.cf.cf_objects.CustomFieldApiId\x12;\n\x0f\x63ustomFieldType\x18\x05 \x01(\x0e\x32\".ocf.cf.cf_objects.CustomFieldType\x12\x39\n\x08newValue\x18\x06 \x01(\x0b\x32\'.ocf.cf.cf_objects.CustomFieldSyncValueB\r\n\x0bobjectApiId*\x1d\n\x0f\x43ustomFieldType\x12\n\n\x06PICKER\x10\x00\x42\x32\n\x1b\x61lation.sdk.ocf.cf.grpc.mdeB\x11\x43\x46MetadataObjectsP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cf.cf_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.ocf.cf.grpc.mdeB\021CFMetadataObjectsP\001'
  _globals['_CUSTOMFIELDAPIID_KEYENTRY']._options = None
  _globals['_CUSTOMFIELDAPIID_KEYENTRY']._serialized_options = b'8\001'
  _globals['_CUSTOMFIELDTYPE']._serialized_start=1253
  _globals['_CUSTOMFIELDTYPE']._serialized_end=1282
  _globals['_CUSTOMFIELDID']._serialized_start=67
  _globals['_CUSTOMFIELDID']._serialized_end=97
  _globals['_CUSTOMFIELDAPIID']._serialized_start=99
  _globals['_CUSTOMFIELDAPIID']._serialized_end=220
  _globals['_CUSTOMFIELDAPIID_KEYENTRY']._serialized_start=178
  _globals['_CUSTOMFIELDAPIID_KEYENTRY']._serialized_end=220
  _globals['_CUSTOMFIELD']._serialized_start=223
  _globals['_CUSTOMFIELD']._serialized_end=466
  _globals['_CUSTOMFIELDPICKERVALUE']._serialized_start=468
  _globals['_CUSTOMFIELDPICKERVALUE']._serialized_end=564
  _globals['_CUSTOMFIELDLINK']._serialized_start=567
  _globals['_CUSTOMFIELDLINK']._serialized_end=811
  _globals['_CUSTOMFIELDSYNCVALUE']._serialized_start=813
  _globals['_CUSTOMFIELDSYNCVALUE']._serialized_end=863
  _globals['_CUSTOMFIELDVALUEUPDATE']._serialized_start=866
  _globals['_CUSTOMFIELDVALUEUPDATE']._serialized_end=1251
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fs/fs_profiling.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x66s/fs_profiling.proto\x12\x0c\x66s.profiling\x1a\x1a\x63ommon/configuration.proto\x1a\x11\x63ommon/auth.proto\"\x9d\x01\n\x14\x46ileProfilingRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x35\n\x0fprofileRequests\x18\x02 \x03(\x0b\x32\x1c.fs.profiling.ProfileRequest\x12\x18\n\x04\x61uth\x18\x03 \x01(\x0b\x32\n.auth.Auth\"\xd3\x01\n\x0eProfileRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x03(\t\x12%\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x14.fs.profiling.Column\x12\x0f\n\x07timeout\x18\x04 \x01(\r\x12\x16\n\x0epopulationSize\x18\x05 \x01(\r\x12\x12\n\nsampleSize\x18\x06 \x01(\r\x12.\n\x10sensitiveColumns\x18\x07 \x03(\x0b\x32\x14.fs.profiling.Column\x12\x13\n\x0bisDirectory\x18\x08 \x01(\x08\"\"\n\x06\x43olumn\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8e\x01\n\x15\x46ileProfilingResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12%\n\nrowSamples\x18\x02 \x03(\x0b\x32\x11.fs.profiling.Row\x12\x1b\n\x13numberOfRowsSampled\x18\x03 \x01(\r\x12\x14\n\x0csecondsTaken\x18\x04 \x01(\r\x12\x0f\n\x07hasMore\x18\x05 \x01(\x08\"\x15\n\x03Row\x12\x0e\n\x06values\x18\x01 \x03(\tB:\n\x1d\x61lation.sdk.fs.grpc.profilingB\tProfilingP\x01Z\x0c\x66s/profilingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fs.fs_profiling_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035alation.sdk.fs.grpc.profilingB\tProfilingP\001Z\014fs/profiling'
  _globals['_FILEPROFILINGREQUEST']._serialized_start=87
  _globals['_FILEPROFILINGREQUEST']._serialized_end=244
  _globals['_PROFILEREQUEST']._serialized_start=247
  _globals['_PROFILEREQUEST']._serialized_end=458
  _globals['_COLUMN']._serialized_start=460
  _globals['_COLUMN']._serialized_end=494
  _globals['_FILEPROFILINGRESPONSE']._serialized_start=497
  _globals['_FILEPROFILINGRESPONSE']._serialized_end=639
  _globals['_ROW']._serialized_start=641
  _globals['_ROW']._serialized_end=662
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/configuration.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import auth_pb2 as common_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63ommon/configuration.proto\x12\x06\x63ommon\x1a\x11\x63ommon/auth.proto\".\n\x10\x41rrayOfTextParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x03(\t\"*\n\x0c\x42ooleanParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"\x7f\n\x0f\x44ictionaryParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x03(\x0b\x32\".common.DictionaryParam.ValueEntry\x1a,\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x14\x45ncryptedBinaryParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"0\n\x12\x45ncryptedTextParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"(\n\nFloatParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\"*\n\x0cIntegerParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05\"(\n\nRadioParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\")\n\x0bSelectParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\'\n\tTextParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"+\n\rTextAreaParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"3\n\tAuthParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x19\n\x05value\x18\x02 \x01(\x0b\x32\n.auth.Auth\"\xaa\x04\n\x11ProtobufParameter\x12/\n\x0b\x61rrayOfText\x18\x01 \x01(\x0b\x32\x18.common.ArrayOfTextParamH\x00\x12\'\n\x07\x62oolean\x18\x02 \x01(\x0b\x32\x14.common.BooleanParamH\x00\x12-\n\ndictionary\x18\x03 \x01(\x0b\x32\x17.common.DictionaryParamH\x00\x12\x37\n\x0f\x65ncryptedBinary\x18\x04 \x01(\x0b\x32\x1c.common.EncryptedBinaryParamH\x00\x12\x33\n\rencryptedText\x18\x05 \x01(\x0b\x32\x1a.common.EncryptedTextParamH\x00\x12#\n\x05\x66loat\x18\x06 \x01(\x0b\x32\x12.common.FloatParamH\x00\x12\'\n\x07integer\x18\x07 \x01(\x0b\x32\x14.common.IntegerParamH\x00\x12!\n\x04text\x18\x08 \x01(\x0b\x32\x11.common.TextParamH\x00\x12)\n\x08textArea\x18\t \x01(\x0b\x32\x15.common.TextAreaParamH\x00\x12#\n\x05radio\x18\n \x01(\x0b\x32\x12.common.RadioParamH\x00\x12%\n\x06select\x18\x0b \x01(\x0b\x32\x13.common.SelectParamH\x00\x12!\n\x04\x61uth\x18\x0c \x01(\x0b\x32\x11.common.AuthParamH\x00\x42\x13\n\x11ProtobufParameter\"\xd4\x02\n\x15ProtobufConfiguration\x12\x41\n\nparameters\x18\x01 \x03(\x0b\x32-.common.ProtobufConfiguration.ParametersEntry\x12Y\n\x16interpolatedParameters\x18\x02 \x03(\x0b\x32\x39.common.ProtobufConfiguration.InterpolatedParametersEntry\x1aL\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.common.ProtobufParameter:\x02\x38\x01\x1aO\n\x1bInterpolatedParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.auth.CAGRequest:\x02\x38\x01\x42,\n\x17\x61lation.sdk.grpc.commonB\x06\x43ommonP\x01Z\x07\x63ommon/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.configuration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.grpc.commonB\006CommonP\001Z\007common/'
  _globals['_DICTIONARYPARAM_VALUEENTRY']._options = None
  _globals['_DICTIONARYPARAM_VALUEENTRY']._serialized_options = b'8\001'
  _globals['_PROTOBUFCONFIGURATION_PARAMETERSENTRY']._options = None
  _globals['_PROTOBUFCONFIGURATION_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_PROTOBUFCONFIGURATION_INTERPOLATEDPARAMETERSENTRY']._options = None
  _globals['_PROTOBUFCONFIGURATION_INTERPOLATEDPARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_ARRAYOFTEXTPARAM']._serialized_start=57
  _globals['_ARRAYOFTEXTPARAM']._serialized_end=103
  _globals['_BOOLEANPARAM']._serialized_start=105
  _globals['_BOOLEANPARAM']._serialized_end=147
  _globals['_DICTIONARYPARAM']._serialized_start=149
  _globals['_DICTIONARYPARAM']._serialized_end=276
  _globals['_DICTIONARYPARAM_VALUEENTRY']._serialized_start=232
  _globals['_DICTIONARYPARAM_VALUEENTRY']._serialized_end=276
  _globals['_ENCRYPTEDBINARYPARAM']._serialized_start=278
  _globals['_ENCRYPTEDBINARYPARAM']._serialized_end=328
  _globals['_ENCRYPTEDTEXTPARAM']._serialized_start=330
  _globals['_ENCRYPTEDTEXTPARAM']._serialized_end=378
  _globals['_FLOATPARAM']._serialized_start=380
  _globals['_FLOATPARAM']._serialized_end=420
  _globals['_INTEGERPARAM']._serialized_start=422
  _globals['_INTEGERPARAM']._serialized_end=464
  _globals['_RADIOPARAM']._serialized_start=466
  _globals['_RADIOPARAM']._serialized_end=506
  _globals['_SELECTPARAM']._serialized_start=508
  _globals['_SELECTPARAM']._serialized_end=549
  _globals['_TEXTPARAM']._serialized_start=551
  _globals['_TEXTPARAM']._serialized_end=590
  _globals['_TEXTAREAPARAM']._serialized_start=592
  _globals['_TEXTAREAPARAM']._serialized_end=635
  _globals['_AUTHPARAM']._serialized_start=637
  _globals['_AUTHPARAM']._serialized_end=688
  _globals['_PROTOBUFPARAMETER']._serialized_start=691
  _globals['_PROTOBUFPARAMETER']._serialized_end=1245
  _globals['_PROTOBUFCONFIGURATION']._serialized_start=1248
  _globals['_PROTOBUFCONFIGURATION']._serialized_end=1588
  _globals['_PROTOBUFCONFIGURATION_PARAMETERSENTRY']._serialized_start=1431
  _globals['_PROTOBUFCONFIGURATION_PARAMETERSENTRY']._serialized_end=1507
  _globals['_PROTOBUFCONFIGURATION_INTERPOLATEDPARAMETERSENTRY']._serialized_start=1509
  _globals['_PROTOBUFCONFIGURATION_INTERPOLATEDPARAMETERSENTRY']._serialized_end=1588
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/job_error.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63ommon/job_error.proto\x12\tjob_error\"*\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9e\x01\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\x12(\n\x07\x63ontext\x18\x05 \x03(\x0b\x32\x17.job_error.ContextEntry\x12*\n\x08severity\x18\x06 \x01(\x0e\x32\x18.job_error.ErrorSeverity*\'\n\rErrorSeverity\x12\x06\n\x02P0\x10\x00\x12\x06\n\x02P1\x10\x01\x12\x06\n\x02P2\x10\x02\x42\x41\n!alation.sdk.grpc.common.job_errorB\x08JobErrorP\x01Z\x10\x63ommon/job_errorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.job_error_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!alation.sdk.grpc.common.job_errorB\010JobErrorP\001Z\020common/job_error'
  _globals['_ERRORSEVERITY']._serialized_start=242
  _globals['_ERRORSEVERITY']._serialized_end=281
  _globals['_CONTEXTENTRY']._serialized_start=37
  _globals['_CONTEXTENTRY']._serialized_end=79
  _globals['_ERROR']._serialized_start=82
  _globals['_ERROR']._serialized_end=240
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/mde.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as common_dot_extraction__objects__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0frdbms/mde.proto\x12\trdbms.mde\x1a\x1a\x63ommon/configuration.proto\x1a\x1f\x63ommon/extraction_objects.proto\x1a\x16\x63ommon/job_error.proto\x1a\x17rdbms/mde_objects.proto\"O\n\x17\x46ilterExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\"\xfc\x01\n\x18\x46ilterExtractionResponse\x12\x41\n\x11\x64\x61tabaseCatalogId\x18\x01 \x01(\x0b\x32$.rdbms.mde_objects.DatabaseCatalogIdH\x00\x12/\n\x08schemaId\x18\x02 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaIdH\x00\x12-\n\x07tableId\x18\x03 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableIdH\x00\x12!\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x1a\n\x18\x46ilterExtractionResponse\"\xd1\x01\n\x19MetadataExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x33\n\x06\x66ilter\x18\x02 \x03(\x0b\x32#.rdbms.mde.FilterExtractionResponse\x12\x19\n\x11is_include_filter\x18\x03 \x01(\x08\x12.\n\x08\x62ookmark\x18\x04 \x01(\x0b\x32\x1c.extraction_objects.Bookmark\"q\n\x12\x45xtractionProgress\x12\x11\n\x07message\x18\x01 \x01(\tH\x00\x12\x32\n\x0e\x63ompletedOtype\x18\x02 \x01(\x0e\x32\x18.rdbms.mde_objects.OtypeH\x00\x42\x14\n\x12\x45xtractionProgress\"\xbe\x03\n\x1aMetadataExtractionResponse\x12=\n\x0f\x64\x61tabaseCatalog\x18\x01 \x01(\x0b\x32\".rdbms.mde_objects.DatabaseCatalogH\x00\x12+\n\x06schema\x18\x02 \x01(\x0b\x32\x19.rdbms.mde_objects.SchemaH\x00\x12)\n\x05table\x18\x03 \x01(\x0b\x32\x18.rdbms.mde_objects.TableH\x00\x12+\n\x06\x63olumn\x18\x04 \x01(\x0b\x32\x19.rdbms.mde_objects.ColumnH\x00\x12/\n\x08\x66unction\x18\x05 \x01(\x0b\x32\x1b.rdbms.mde_objects.FunctionH\x00\x12;\n\x12\x65xtractionProgress\x18\x06 \x01(\x0b\x32\x1d.rdbms.mde.ExtractionProgressH\x00\x12!\n\x05\x65rror\x18\x07 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x12\x30\n\x08\x62ookmark\x18\x08 \x01(\x0b\x32\x1c.extraction_objects.BookmarkH\x00\x42\x19\n\x17\x45xtractMetadataResponse\"\xac\x01\n\x16TableExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12+\n\x07tableId\x18\x02 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableId\x12/\n\ttableType\x18\x03 \x01(\x0b\x32\x1c.rdbms.mde_objects.TableType\"\x8c\x01\n\x17TableExtractionResponse\x12)\n\x05table\x18\x01 \x01(\x0b\x32\x18.rdbms.mde_objects.TableH\x00\x12+\n\x06\x63olumn\x18\x02 \x01(\x0b\x32\x19.rdbms.mde_objects.ColumnH\x00\x42\x19\n\x17TableExtractionResponseB=\n\x1a\x61lation.sdk.rdbms.grpc.mdeB\x12MetadataExtractionP\x01Z\trdbms/mdeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.mde_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032alation.sdk.rdbms.grpc.mdeB\022MetadataExtractionP\001Z\trdbms/mde'
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_start=140
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_end=219
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_start=222
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_end=474
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_start=477
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_end=686
  _globals['_EXTRACTIONPROGRESS']._serialized_start=688
  _globals['_EXTRACTIONPROGRESS']._serialized_end=801
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_start=804
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_end=1250
  _globals['_TABLEEXTRACTIONREQUEST']._serialized_start=1253
  _globals['_TABLEEXTRACTIONREQUEST']._serialized_end=1425
  _globals['_TABLEEXTRACTIONRESPONSE']._serialized_start=1428
  _globals['_TABLEEXTRACTIONRESPONSE']._serialized_end=1568
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorSeverity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    P0: _ClassVar[ErrorSeverity]
    P1: _ClassVar[ErrorSeverity]
    P2: _ClassVar[ErrorSeverity]
P0: ErrorSeverity
P1: ErrorSeverity
P2: ErrorSeverity

class ContextEntry(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class Error(_message.Message):
    __slots__ = ("message", "name", "category", "action", "context", "severity")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    SEVERITY_FIELD_NUMBER: _ClassVar[int]
    message: str
    name: str
    category: str
    action: str
    context: _containers.RepeatedCompositeFieldContainer[ContextEntry]
    severity: ErrorSeverity
    def __init__(self, message: _Optional[str] = ..., name: _Optional[str] = ..., category: _Optional[str] = ..., action: _Optional[str] = ..., context: _Optional[_Iterable[_Union[ContextEntry, _Mapping]]] = ..., severity: _Optional[_Union[ErrorSeverity, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cf/cf_sync.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cf import cf_objects_pb2 as cf_dot_cf__objects__pb2
from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import error_pb2 as common_dot_error__pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63\x66/cf_sync.proto\x12\x0cocf.cf.rdbms\x1a\x13\x63\x66/cf_objects.proto\x1a\x11\x63ommon/auth.proto\x1a\x1a\x63ommon/configuration.proto\x1a\x12\x63ommon/error.proto\x1a\x17rdbms/mde_objects.proto\"\xe4\x01\n\x17\x43ustomFieldSyncResponse\x12/\n\x08schemaId\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaIdH\x00\x12-\n\x07tableId\x18\x02 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableIdH\x00\x12/\n\x08\x63olumnId\x18\x03 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnIdH\x00\x12\x1d\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x0c.error.ErrorH\x00\x42\x19\n\x17\x43ustomFieldSyncResponse\"\xb4\x01\n\x16\x43ustomFieldSyncRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x18\n\x04\x61uth\x18\x02 \x01(\x0b\x32\n.auth.Auth\x12J\n\x17\x63ustomFieldValueUpdates\x18\x03 \x03(\x0b\x32).ocf.cf.cf_objects.CustomFieldValueUpdate2z\n\x14RdbmsCustomFieldSync\x12\x62\n\x0f\x43ustomFieldSync\x12$.ocf.cf.rdbms.CustomFieldSyncRequest\x1a%.ocf.cf.rdbms.CustomFieldSyncResponse\"\x00\x30\x01\x42)\n\x17\x61lation.sdk.ocf.cf.grpcB\x0cMetadataSyncP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cf.cf_sync_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.ocf.cf.grpcB\014MetadataSyncP\001'
  _globals['_CUSTOMFIELDSYNCRESPONSE']._serialized_start=148
  _globals['_CUSTOMFIELDSYNCRESPONSE']._serialized_end=376
  _globals['_CUSTOMFIELDSYNCREQUEST']._serialized_start=379
  _globals['_CUSTOMFIELDSYNCREQUEST']._serialized_end=559
  _globals['_RDBMSCUSTOMFIELDSYNC']._serialized_start=561
  _globals['_RDBMSCUSTOMFIELDSYNC']._serialized_end=683
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.rdbms import mde_objects_pb2 as _mde_objects_pb2
from queryservice_client.protobuf.common import datasource_pb2 as _datasource_pb2
from asset import filter_extraction_objects_pb2 as _filter_extraction_objects_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ModelType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TABLE: _ClassVar[ModelType]
    VIEW: _ClassVar[ModelType]
    INCREMENTAL: _ClassVar[ModelType]
    EPHEMERAL: _ClassVar[ModelType]
TABLE: ModelType
VIEW: ModelType
INCREMENTAL: ModelType
EPHEMERAL: ModelType

class Dataflow(_message.Message):
    __slots__ = ("content", "facets")
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    FACETS_FIELD_NUMBER: _ClassVar[int]
    content: str
    facets: DataflowFacets
    def __init__(self, content: _Optional[str] = ..., facets: _Optional[_Union[DataflowFacets, _Mapping]] = ...) -> None: ...

class NativeObject(_message.Message):
    __slots__ = ("data_source", "schema_id", "table_id", "column_id", "path_id", "facets")
    DATA_SOURCE_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_ID_FIELD_NUMBER: _ClassVar[int]
    COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_ID_FIELD_NUMBER: _ClassVar[int]
    FACETS_FIELD_NUMBER: _ClassVar[int]
    data_source: _datasource_pb2.DataSource
    schema_id: _mde_objects_pb2.SchemaId
    table_id: _mde_objects_pb2.TableId
    column_id: _mde_objects_pb2.ColumnId
    path_id: PathId
    facets: DatasourceFacets
    def __init__(self, data_source: _Optional[_Union[_datasource_pb2.DataSource, _Mapping]] = ..., schema_id: _Optional[_Union[_mde_objects_pb2.SchemaId, _Mapping]] = ..., table_id: _Optional[_Union[_mde_objects_pb2.TableId, _Mapping]] = ..., column_id: _Optional[_Union[_mde_objects_pb2.ColumnId, _Mapping]] = ..., path_id: _Optional[_Union[PathId, _Mapping]] = ..., facets: _Optional[_Union[DatasourceFacets, _Mapping]] = ...) -> None: ...

class LineageObject(_message.Message):
    __slots__ = ("native_object",)
    NATIVE_OBJECT_FIELD_NUMBER: _ClassVar[int]
    native_object: NativeObject
    def __init__(self, native_object: _Optional[_Union[NativeObject, _Mapping]] = ...) -> None: ...

class LineagePath(_message.Message):
    __slots__ = ("sources", "dataflow", "target", "fullyQualifiedPath")
    SOURCES_FIELD_NUMBER: _ClassVar[int]
    DATAFLOW_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    FULLYQUALIFIEDPATH_FIELD_NUMBER: _ClassVar[int]
    sources: _containers.RepeatedCompositeFieldContainer[LineageObject]
    dataflow: Dataflow
    target: LineageObject
    fullyQualifiedPath: PathId
    def __init__(self, sources: _Optional[_Iterable[_Union[LineageObject, _Mapping]]] = ..., dataflow: _Optional[_Union[Dataflow, _Mapping]] = ..., target: _Optional[_Union[LineageObject, _Mapping]] = ..., fullyQualifiedPath: _Optional[_Union[PathId, _Mapping]] = ...) -> None: ...

class ModelTypeFacet(_message.Message):
    __slots__ = ("modelType",)
    MODELTYPE_FIELD_NUMBER: _ClassVar[int]
    modelType: ModelType
    def __init__(self, modelType: _Optional[_Union[ModelType, str]] = ...) -> None: ...

class DatasourceFacets(_message.Message):
    __slots__ = ("modelTypeFacet", "modelFacet")
    MODELTYPEFACET_FIELD_NUMBER: _ClassVar[int]
    MODELFACET_FIELD_NUMBER: _ClassVar[int]
    modelTypeFacet: ModelTypeFacet
    modelFacet: ModelFacet
    def __init__(self, modelTypeFacet: _Optional[_Union[ModelTypeFacet, _Mapping]] = ..., modelFacet: _Optional[_Union[ModelFacet, _Mapping]] = ...) -> None: ...

class PathId(_message.Message):
    __slots__ = ("external_id", "path")
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    external_id: str
    path: _filter_extraction_objects_pb2.Path
    def __init__(self, external_id: _Optional[str] = ..., path: _Optional[_Union[_filter_extraction_objects_pb2.Path, _Mapping]] = ...) -> None: ...

class ModelFacet(_message.Message):
    __slots__ = ("externalId", "columnNames")
    EXTERNALID_FIELD_NUMBER: _ClassVar[int]
    COLUMNNAMES_FIELD_NUMBER: _ClassVar[int]
    externalId: str
    columnNames: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, externalId: _Optional[str] = ..., columnNames: _Optional[_Iterable[str]] = ...) -> None: ...

class CodeFacet(_message.Message):
    __slots__ = ("code",)
    CODE_FIELD_NUMBER: _ClassVar[int]
    code: str
    def __init__(self, code: _Optional[str] = ...) -> None: ...

class ExternalURLFacet(_message.Message):
    __slots__ = ("externalUrl",)
    EXTERNALURL_FIELD_NUMBER: _ClassVar[int]
    externalUrl: str
    def __init__(self, externalUrl: _Optional[str] = ...) -> None: ...

class DataFlowGroupFacet(_message.Message):
    __slots__ = ("groupName",)
    GROUPNAME_FIELD_NUMBER: _ClassVar[int]
    groupName: str
    def __init__(self, groupName: _Optional[str] = ...) -> None: ...

class DataflowFacets(_message.Message):
    __slots__ = ("codeFacet", "dataflowGroupFacet", "externalURLFacet", "dbType")
    CODEFACET_FIELD_NUMBER: _ClassVar[int]
    DATAFLOWGROUPFACET_FIELD_NUMBER: _ClassVar[int]
    EXTERNALURLFACET_FIELD_NUMBER: _ClassVar[int]
    DBTYPE_FIELD_NUMBER: _ClassVar[int]
    codeFacet: CodeFacet
    dataflowGroupFacet: DataFlowGroupFacet
    externalURLFacet: ExternalURLFacet
    dbType: str
    def __init__(self, codeFacet: _Optional[_Union[CodeFacet, _Mapping]] = ..., dataflowGroupFacet: _Optional[_Union[DataFlowGroupFacet, _Mapping]] = ..., externalURLFacet: _Optional[_Union[ExternalURLFacet, _Mapping]] = ..., dbType: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Filter(_message.Message):
    __slots__ = ("external_id", "path", "additionalInfo")
    class AdditionalInfoEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    ADDITIONALINFO_FIELD_NUMBER: _ClassVar[int]
    external_id: str
    path: Path
    additionalInfo: _containers.ScalarMap[str, str]
    def __init__(self, external_id: _Optional[str] = ..., path: _Optional[_Union[Path, _Mapping]] = ..., additionalInfo: _Optional[_Mapping[str, str]] = ...) -> None: ...

class Path(_message.Message):
    __slots__ = ("path", "delimiter")
    PATH_FIELD_NUMBER: _ClassVar[int]
    DELIMITER_FIELD_NUMBER: _ClassVar[int]
    path: _containers.RepeatedScalarFieldContainer[str]
    delimiter: str
    def __init__(self, path: _Optional[_Iterable[str]] = ..., delimiter: _Optional[str] = ...) -> None: ...



from queryservice_client.protobuf.rdbms.query_pb2 import QueryResultObject

from queryservice_client.stream.stream import Stream
from queryservice_client.stream.delimitedstream import DelimitedStream
from queryservice_client.stream.peekable import Peekable

class ResultSetStream(Peekable):

    @staticmethod
    def check(obj: QueryResultObject):
        return obj.HasField("endOfResultSet")

    def __init__(self, stream: Stream):
        self.stream = DelimitedStream(stream, ResultSetStream.check)

    def has_next(self):
        return self.stream.has_next()

    def __next__(self):
        return next(self.stream)

    def peek(self):
        return self.stream.peek()

    def __iter__(self):
        return self


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/operations.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import checks_pb2 as common_dot_checks__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63ommon/operations.proto\x12\nocf.common\x1a\x13\x63ommon/checks.proto2M\n\nOperations\x12?\n\x0ePreflightCheck\x12\x14.checks.CheckRequest\x1a\x13.checks.CheckResult\"\x00\x30\x01\x42N\n\"alation.sdk.grpc.common.operationsB\x13\x43onnectorOperationsP\x01Z\x11\x63ommon/operationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.operations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"alation.sdk.grpc.common.operationsB\023ConnectorOperationsP\001Z\021common/operations'
  _globals['_OPERATIONS']._serialized_start=60
  _globals['_OPERATIONS']._serialized_end=137
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from fs import mde_objects_pb2 as _mde_objects_pb2
from queryservice_client.protobuf.common import job_error_pb2 as _job_error_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FilterExtractionRequest(_message.Message):
    __slots__ = ("configuration",)
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ...) -> None: ...

class FilterExtractionResponse(_message.Message):
    __slots__ = ("path",)
    PATH_FIELD_NUMBER: _ClassVar[int]
    path: _mde_objects_pb2.Path
    def __init__(self, path: _Optional[_Union[_mde_objects_pb2.Path, _Mapping]] = ...) -> None: ...

class MetadataExtractionRequest(_message.Message):
    __slots__ = ("configuration", "bookmark", "filter", "is_include_filter")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    IS_INCLUDE_FILTER_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    bookmark: _containers.RepeatedCompositeFieldContainer[_mde_objects_pb2.Bookmark]
    filter: _mde_objects_pb2.Filter
    is_include_filter: bool
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., bookmark: _Optional[_Iterable[_Union[_mde_objects_pb2.Bookmark, _Mapping]]] = ..., filter: _Optional[_Union[_mde_objects_pb2.Filter, _Mapping]] = ..., is_include_filter: bool = ...) -> None: ...

class MetadataExtractionResponse(_message.Message):
    __slots__ = ("file", "bookmark", "extractionProgress", "error")
    FILE_FIELD_NUMBER: _ClassVar[int]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    EXTRACTIONPROGRESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    file: _mde_objects_pb2.File
    bookmark: _mde_objects_pb2.Bookmark
    extractionProgress: _mde_objects_pb2.ExtractionProgress
    error: _job_error_pb2.Error
    def __init__(self, file: _Optional[_Union[_mde_objects_pb2.File, _Mapping]] = ..., bookmark: _Optional[_Union[_mde_objects_pb2.Bookmark, _Mapping]] = ..., extractionProgress: _Optional[_Union[_mde_objects_pb2.ExtractionProgress, _Mapping]] = ..., error: _Optional[_Union[_job_error_pb2.Error, _Mapping]] = ...) -> None: ...

class ColumnExtractionResponse(_message.Message):
    __slots__ = ("column", "bookmark", "extractionProgress", "error")
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    EXTRACTIONPROGRESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    column: _mde_objects_pb2.Column
    bookmark: _mde_objects_pb2.Bookmark
    extractionProgress: _mde_objects_pb2.ExtractionProgress
    error: _job_error_pb2.Error
    def __init__(self, column: _Optional[_Union[_mde_objects_pb2.Column, _Mapping]] = ..., bookmark: _Optional[_Union[_mde_objects_pb2.Bookmark, _Mapping]] = ..., extractionProgress: _Optional[_Union[_mde_objects_pb2.ExtractionProgress, _Mapping]] = ..., error: _Optional[_Union[_job_error_pb2.Error, _Mapping]] = ...) -> None: ...



from queryservice_client.stream.peekable import Peekable
from queryservice_client.stream.stream import Stream

class DelimitedStream(Peekable):
    def __init__(self, stream: Stream, is_delimiter):
        self.stream = stream
        self.done = False
        self.is_delimiter = is_delimiter

    def has_next(self):
        if self.done:
            return False
        peek = self.stream.peek()
        if peek is None:
            self.done = True
            return False
        elif self.is_delimiter(peek):
            self.done = True
            next(self.stream)
            return False
        else:
            return True

    def __next__(self):
        if self.done:
            raise StopIteration()
        peek = self.stream.peek()
        if peek is None:
            self.done = True
            raise StopIteration()
        elif self.is_delimiter(peek):
            self.done = True
            next(self.stream)
            raise StopIteration()
        else:
            return next(self.stream)

    def peek(self):
        if self.done:
            return None
        peek = self.stream.peek()
        if peek is None:
            self.done = True
            return None
        elif self.is_delimiter(peek):
            self.done = True
            next(self.stream)
            return None
        else:
            return peek

    def __iter__(self):
        return self


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bi import certify_pb2 as bi_dot_certify__pb2
from bi import mde_pb2 as bi_dot_mde__pb2
from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class BiStub(object):
    """Interface exported by the server.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigurationVerification = channel.unary_unary(
                '/bi.Bi/ConfigurationVerification',
                request_serializer=common_dot_verify__pb2.Request.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListFileSystem = channel.unary_stream(
                '/bi.Bi/ListFileSystem',
                request_serializer=bi_dot_mde__pb2.ListFileSystemRequest.SerializeToString,
                response_deserializer=bi_dot_mde__pb2.BIObjectResponse.FromString,
                )
        self.RunFullExtraction = channel.unary_stream(
                '/bi.Bi/RunFullExtraction',
                request_serializer=bi_dot_mde__pb2.RunFullExtractionRequest.SerializeToString,
                response_deserializer=bi_dot_mde__pb2.BIObjectResponse.FromString,
                )
        self.propagateCertification = channel.unary_stream(
                '/bi.Bi/propagateCertification',
                request_serializer=bi_dot_certify__pb2.PropagateCertificationRequest.SerializeToString,
                response_deserializer=bi_dot_mde__pb2.BIObjectResponse.FromString,
                )


class BiServicer(object):
    """Interface exported by the server.
    """

    def ConfigurationVerification(self, request, context):
        """Verify that the connector has been configured correctly.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFileSystem(self, request, context):
        """Return the BI Server folder structure.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunFullExtraction(self, request, context):
        """Run full metadata extraction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def propagateCertification(self, request, context):
        """Certify or de-certify a BI object.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigurationVerification': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigurationVerification,
                    request_deserializer=common_dot_verify__pb2.Request.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListFileSystem': grpc.unary_stream_rpc_method_handler(
                    servicer.ListFileSystem,
                    request_deserializer=bi_dot_mde__pb2.ListFileSystemRequest.FromString,
                    response_serializer=bi_dot_mde__pb2.BIObjectResponse.SerializeToString,
            ),
            'RunFullExtraction': grpc.unary_stream_rpc_method_handler(
                    servicer.RunFullExtraction,
                    request_deserializer=bi_dot_mde__pb2.RunFullExtractionRequest.FromString,
                    response_serializer=bi_dot_mde__pb2.BIObjectResponse.SerializeToString,
            ),
            'propagateCertification': grpc.unary_stream_rpc_method_handler(
                    servicer.propagateCertification,
                    request_deserializer=bi_dot_certify__pb2.PropagateCertificationRequest.FromString,
                    response_serializer=bi_dot_mde__pb2.BIObjectResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bi.Bi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Bi(object):
    """Interface exported by the server.
    """

    @staticmethod
    def ConfigurationVerification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bi.Bi/ConfigurationVerification',
            common_dot_verify__pb2.Request.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFileSystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/bi.Bi/ListFileSystem',
            bi_dot_mde__pb2.ListFileSystemRequest.SerializeToString,
            bi_dot_mde__pb2.BIObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunFullExtraction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/bi.Bi/RunFullExtraction',
            bi_dot_mde__pb2.RunFullExtractionRequest.SerializeToString,
            bi_dot_mde__pb2.BIObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def propagateCertification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/bi.Bi/propagateCertification',
            bi_dot_certify__pb2.PropagateCertificationRequest.SerializeToString,
            bi_dot_mde__pb2.BIObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import auth_pb2 as _auth_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FileProfilingRequest(_message.Message):
    __slots__ = ("configuration", "profileRequests", "auth")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    PROFILEREQUESTS_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    profileRequests: _containers.RepeatedCompositeFieldContainer[ProfileRequest]
    auth: _auth_pb2.Auth
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., profileRequests: _Optional[_Iterable[_Union[ProfileRequest, _Mapping]]] = ..., auth: _Optional[_Union[_auth_pb2.Auth, _Mapping]] = ...) -> None: ...

class ProfileRequest(_message.Message):
    __slots__ = ("id", "path", "columns", "timeout", "populationSize", "sampleSize", "sensitiveColumns", "isDirectory")
    ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    POPULATIONSIZE_FIELD_NUMBER: _ClassVar[int]
    SAMPLESIZE_FIELD_NUMBER: _ClassVar[int]
    SENSITIVECOLUMNS_FIELD_NUMBER: _ClassVar[int]
    ISDIRECTORY_FIELD_NUMBER: _ClassVar[int]
    id: str
    path: _containers.RepeatedScalarFieldContainer[str]
    columns: _containers.RepeatedCompositeFieldContainer[Column]
    timeout: int
    populationSize: int
    sampleSize: int
    sensitiveColumns: _containers.RepeatedCompositeFieldContainer[Column]
    isDirectory: bool
    def __init__(self, id: _Optional[str] = ..., path: _Optional[_Iterable[str]] = ..., columns: _Optional[_Iterable[_Union[Column, _Mapping]]] = ..., timeout: _Optional[int] = ..., populationSize: _Optional[int] = ..., sampleSize: _Optional[int] = ..., sensitiveColumns: _Optional[_Iterable[_Union[Column, _Mapping]]] = ..., isDirectory: bool = ...) -> None: ...

class Column(_message.Message):
    __slots__ = ("id", "name")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    def __init__(self, id: _Optional[int] = ..., name: _Optional[str] = ...) -> None: ...

class FileProfilingResponse(_message.Message):
    __slots__ = ("id", "rowSamples", "numberOfRowsSampled", "secondsTaken", "hasMore")
    ID_FIELD_NUMBER: _ClassVar[int]
    ROWSAMPLES_FIELD_NUMBER: _ClassVar[int]
    NUMBEROFROWSSAMPLED_FIELD_NUMBER: _ClassVar[int]
    SECONDSTAKEN_FIELD_NUMBER: _ClassVar[int]
    HASMORE_FIELD_NUMBER: _ClassVar[int]
    id: str
    rowSamples: _containers.RepeatedCompositeFieldContainer[Row]
    numberOfRowsSampled: int
    secondsTaken: int
    hasMore: bool
    def __init__(self, id: _Optional[str] = ..., rowSamples: _Optional[_Iterable[_Union[Row, _Mapping]]] = ..., numberOfRowsSampled: _Optional[int] = ..., secondsTaken: _Optional[int] = ..., hasMore: bool = ...) -> None: ...

class Row(_message.Message):
    __slots__ = ("values",)
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, values: _Optional[_Iterable[str]] = ...) -> None: ...



from dl import dl_objects_pb2 as _dl_objects_pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as _mde_pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as _mde_objects_pb2
from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as _extraction_objects_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LineageExtractionRequest(_message.Message):
    __slots__ = ("configuration", "schemaIds", "is_include_filter", "bookmark")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    SCHEMAIDS_FIELD_NUMBER: _ClassVar[int]
    IS_INCLUDE_FILTER_FIELD_NUMBER: _ClassVar[int]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    schemaIds: _containers.RepeatedCompositeFieldContainer[_mde_objects_pb2.SchemaId]
    is_include_filter: bool
    bookmark: _extraction_objects_pb2.Bookmark
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., schemaIds: _Optional[_Iterable[_Union[_mde_objects_pb2.SchemaId, _Mapping]]] = ..., is_include_filter: bool = ..., bookmark: _Optional[_Union[_extraction_objects_pb2.Bookmark, _Mapping]] = ...) -> None: ...

class LineageExtractionResponse(_message.Message):
    __slots__ = ("lineagePath", "bookmark")
    LINEAGEPATH_FIELD_NUMBER: _ClassVar[int]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    lineagePath: _dl_objects_pb2.LineagePath
    bookmark: _extraction_objects_pb2.Bookmark
    def __init__(self, lineagePath: _Optional[_Union[_dl_objects_pb2.LineagePath, _Mapping]] = ..., bookmark: _Optional[_Union[_extraction_objects_pb2.Bookmark, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CAGRequest(_message.Message):
    __slots__ = ("token",)
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class CAGResponse(_message.Message):
    __slots__ = ("success", "code", "message", "protoName", "protoObj")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    PROTONAME_FIELD_NUMBER: _ClassVar[int]
    PROTOOBJ_FIELD_NUMBER: _ClassVar[int]
    success: bool
    code: str
    message: str
    protoName: str
    protoObj: bytes
    def __init__(self, success: bool = ..., code: _Optional[str] = ..., message: _Optional[str] = ..., protoName: _Optional[str] = ..., protoObj: _Optional[bytes] = ...) -> None: ...



from cf import cf_objects_pb2 as _cf_objects_pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as _mde_pb2
from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CustomFieldExtractionRequest(_message.Message):
    __slots__ = ("configuration", "filter", "is_include_filter")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    IS_INCLUDE_FILTER_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    filter: _containers.RepeatedCompositeFieldContainer[_mde_pb2.FilterExtractionResponse]
    is_include_filter: bool
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., filter: _Optional[_Iterable[_Union[_mde_pb2.FilterExtractionResponse, _Mapping]]] = ..., is_include_filter: bool = ...) -> None: ...

class CustomFieldExtractionResponse(_message.Message):
    __slots__ = ("field", "link")
    FIELD_FIELD_NUMBER: _ClassVar[int]
    LINK_FIELD_NUMBER: _ClassVar[int]
    field: _cf_objects_pb2.CustomField
    link: _cf_objects_pb2.CustomFieldLink
    def __init__(self, field: _Optional[_Union[_cf_objects_pb2.CustomField, _Mapping]] = ..., link: _Optional[_Union[_cf_objects_pb2.CustomFieldLink, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2
from fs import fs_profiling_pb2 as fs_dot_fs__profiling__pb2
from fs import mde_pb2 as fs_dot_mde__pb2
from fs import volume_check_pb2 as fs_dot_volume__check__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class FileSystemStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigurationVerification = channel.unary_unary(
                '/fs.FileSystem/ConfigurationVerification',
                request_serializer=common_dot_verify__pb2.Request.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.FilterExtraction = channel.unary_stream(
                '/fs.FileSystem/FilterExtraction',
                request_serializer=fs_dot_mde__pb2.FilterExtractionRequest.SerializeToString,
                response_deserializer=fs_dot_mde__pb2.FilterExtractionResponse.FromString,
                )
        self.MetadataExtraction = channel.unary_stream(
                '/fs.FileSystem/MetadataExtraction',
                request_serializer=fs_dot_mde__pb2.MetadataExtractionRequest.SerializeToString,
                response_deserializer=fs_dot_mde__pb2.MetadataExtractionResponse.FromString,
                )
        self.ColumnExtraction = channel.unary_stream(
                '/fs.FileSystem/ColumnExtraction',
                request_serializer=fs_dot_mde__pb2.MetadataExtractionRequest.SerializeToString,
                response_deserializer=fs_dot_mde__pb2.ColumnExtractionResponse.FromString,
                )
        self.FileProfiling = channel.unary_stream(
                '/fs.FileSystem/FileProfiling',
                request_serializer=fs_dot_fs__profiling__pb2.FileProfilingRequest.SerializeToString,
                response_deserializer=fs_dot_fs__profiling__pb2.FileProfilingResponse.FromString,
                )
        self.VolumeCheck = channel.unary_stream(
                '/fs.FileSystem/VolumeCheck',
                request_serializer=fs_dot_volume__check__pb2.VolumeCheckRequest.SerializeToString,
                response_deserializer=fs_dot_volume__check__pb2.VolumeCheckResponse.FromString,
                )


class FileSystemServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigurationVerification(self, request, context):
        """Verify that the connector has been configured correctly.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FilterExtraction(self, request, context):
        """Run extraction to fetch list of filters. Optional based on application configuration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MetadataExtraction(self, request, context):
        """Run full or selective extraction based on filters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ColumnExtraction(self, request, context):
        """Run Column Metadata extraction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FileProfiling(self, request, context):
        """Run Profiling on file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VolumeCheck(self, request, context):
        """Run Volume Check on bucket(s)/container(s).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FileSystemServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigurationVerification': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigurationVerification,
                    request_deserializer=common_dot_verify__pb2.Request.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'FilterExtraction': grpc.unary_stream_rpc_method_handler(
                    servicer.FilterExtraction,
                    request_deserializer=fs_dot_mde__pb2.FilterExtractionRequest.FromString,
                    response_serializer=fs_dot_mde__pb2.FilterExtractionResponse.SerializeToString,
            ),
            'MetadataExtraction': grpc.unary_stream_rpc_method_handler(
                    servicer.MetadataExtraction,
                    request_deserializer=fs_dot_mde__pb2.MetadataExtractionRequest.FromString,
                    response_serializer=fs_dot_mde__pb2.MetadataExtractionResponse.SerializeToString,
            ),
            'ColumnExtraction': grpc.unary_stream_rpc_method_handler(
                    servicer.ColumnExtraction,
                    request_deserializer=fs_dot_mde__pb2.MetadataExtractionRequest.FromString,
                    response_serializer=fs_dot_mde__pb2.ColumnExtractionResponse.SerializeToString,
            ),
            'FileProfiling': grpc.unary_stream_rpc_method_handler(
                    servicer.FileProfiling,
                    request_deserializer=fs_dot_fs__profiling__pb2.FileProfilingRequest.FromString,
                    response_serializer=fs_dot_fs__profiling__pb2.FileProfilingResponse.SerializeToString,
            ),
            'VolumeCheck': grpc.unary_stream_rpc_method_handler(
                    servicer.VolumeCheck,
                    request_deserializer=fs_dot_volume__check__pb2.VolumeCheckRequest.FromString,
                    response_serializer=fs_dot_volume__check__pb2.VolumeCheckResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fs.FileSystem', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FileSystem(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigurationVerification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fs.FileSystem/ConfigurationVerification',
            common_dot_verify__pb2.Request.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FilterExtraction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/fs.FileSystem/FilterExtraction',
            fs_dot_mde__pb2.FilterExtractionRequest.SerializeToString,
            fs_dot_mde__pb2.FilterExtractionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MetadataExtraction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/fs.FileSystem/MetadataExtraction',
            fs_dot_mde__pb2.MetadataExtractionRequest.SerializeToString,
            fs_dot_mde__pb2.MetadataExtractionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ColumnExtraction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/fs.FileSystem/ColumnExtraction',
            fs_dot_mde__pb2.MetadataExtractionRequest.SerializeToString,
            fs_dot_mde__pb2.ColumnExtractionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FileProfiling(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/fs.FileSystem/FileProfiling',
            fs_dot_fs__profiling__pb2.FileProfilingRequest.SerializeToString,
            fs_dot_fs__profiling__pb2.FileProfilingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VolumeCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/fs.FileSystem/VolumeCheck',
            fs_dot_volume__check__pb2.VolumeCheckRequest.SerializeToString,
            fs_dot_volume__check__pb2.VolumeCheckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fs/fs.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2
from fs import mde_pb2 as fs_dot_mde__pb2
from fs import fs_profiling_pb2 as fs_dot_fs__profiling__pb2
from fs import volume_check_pb2 as fs_dot_volume__check__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x66s/fs.proto\x12\x02\x66s\x1a\x1bgoogle/protobuf/empty.proto\x1a\x13\x63ommon/verify.proto\x1a\x0c\x66s/mde.proto\x1a\x15\x66s/fs_profiling.proto\x1a\x15\x66s/volume_check.proto2\xa9\x04\n\nFileSystem\x12\x46\n\x19\x43onfigurationVerification\x12\x0f.verify.Request\x1a\x16.google.protobuf.Empty\"\x00\x12Y\n\x10\x46ilterExtraction\x12\x1f.fs.mde.FilterExtractionRequest\x1a .fs.mde.FilterExtractionResponse\"\x00\x30\x01\x12_\n\x12MetadataExtraction\x12!.fs.mde.MetadataExtractionRequest\x1a\".fs.mde.MetadataExtractionResponse\"\x00\x30\x01\x12[\n\x10\x43olumnExtraction\x12!.fs.mde.MetadataExtractionRequest\x1a .fs.mde.ColumnExtractionResponse\"\x00\x30\x01\x12\\\n\rFileProfiling\x12\".fs.profiling.FileProfilingRequest\x1a#.fs.profiling.FileProfilingResponse\"\x00\x30\x01\x12\\\n\x0bVolumeCheck\x12#.fs.volume_check.VolumeCheckRequest\x1a$.fs.volume_check.VolumeCheckResponse\"\x00\x30\x01\x42%\n\x13\x61lation.sdk.fs.grpcB\x07\x46SProtoP\x01Z\x03\x66s/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fs.fs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023alation.sdk.fs.grpcB\007FSProtoP\001Z\003fs/'
  _globals['_FILESYSTEM']._serialized_start=130
  _globals['_FILESYSTEM']._serialized_end=683
# @@protoc_insertion_point(module_scope)



import base64
from enum import Enum
from queryservice_client.protobuf.rdbms.query_pb2 import RowData, Null, Endianness

from datetime import datetime, timezone, timedelta
from typing import Any, List
from decimal import Decimal

class Type(Enum):
    NULL = 0
    DOUBLE = 1
    FLOAT = 2
    INT32 = 3
    INT64 = 4
    UINT32 = 5
    UINT64 = 6
    BOOL = 7
    STRING = 8
    BYTES = 9
    DATE = 10
    ARRAY = 11
    STRUCT = 12
    BIGINT = 13
    BIGDECIMAL = 14

class Data:
    def __init__(self, data: RowData):
        self.data = data

    @staticmethod
    def create(row_data: RowData) -> 'Data':
        data_case = row_data.WhichOneof('data')
        if data_case == 'null':
            return NullData(row_data)
        elif data_case == 'double':
            return DoubleData(row_data)
        elif data_case == 'float':
            return FloatData(row_data)
        elif data_case == 'int32':
            return Int32Data(row_data)
        elif data_case == 'int64':
            return Int64Data(row_data)
        elif data_case == 'uint32':
            return Uint32Data(row_data)
        elif data_case == 'uint64':
            return Uint64Data(row_data)
        elif data_case == 'bool':
            return BoolData(row_data)
        elif data_case == 'string':
            return StringData(row_data)
        elif data_case == 'bytes':
            return BytesData(row_data)
        elif data_case == 'date':
            return DateData(row_data)
        elif data_case == 'array':
            return ArrayData(row_data)
        elif data_case == 'struct':
            return StructData(row_data)
        elif data_case == 'bigInt':
            return BigIntData(row_data)
        elif data_case == 'bigDecimal':
            return BigDecimalData(row_data)
        else:
            raise RuntimeError(f"Unknown datatype: {data_case}")

    def type(self) -> Type:
        raise NotImplementedError

    def get(self) -> Any:
        raise NotImplementedError

    def __eq__(self, other: Any) -> bool:
        if isinstance(other, Data):
            return self.data == other.data
        return False

    def __hash__(self) -> int:
        return hash(self.data)

    def __str__(self) -> str:
        return str(self.get())


class NullData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.NULL

    def get(self) -> None:
        return None

    def __str__(self) -> str:
        return "NULL"
    
class Int64Data(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.INT64

    def get(self) -> int:
        return self.data.int64
    
class Int32Data(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.INT32

    def get(self) -> int:
        return self.data.int32
    
class FloatData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.FLOAT

    def get(self) -> float:
        return self.data.float

class DoubleData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.DOUBLE

    def get(self) -> float:
        return self.data.double

    def __str__(self) -> str:
        return str(self.get())
    
class DateData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.DATE

    def get(self) -> datetime:
        date = self.data.date
        epoch_seconds = date.timestamp.seconds
        nanos = date.timestamp.nanos
        offset_minutes = date.timezoneOffsetMinutes
        offset = timedelta(minutes=offset_minutes)
        return datetime.fromtimestamp(epoch_seconds + nanos / 1e9, tz=timezone(offset))

    def __str__(self) -> str:
        return self.get().isoformat()

class StringData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.STRING

    def get(self) -> str:
        return self.data.string

    def __str__(self) -> str:
        return self.get()


class BytesData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.BYTES

    def get(self) -> str:
        return base64.b64encode(self.data.bytes).decode('utf-8')
    

class BoolData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.BOOL

    def get(self) -> bool:
        return self.data.bool

    def __str__(self) -> str:
        return str(self.get())
    

class BigIntData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.BIGINT

    def get(self) -> int:
        big_int = self.data.bigInt
        bytes_value = big_int.value
        if big_int.endianness == Endianness.LITTLE:
            bytes_value = bytes_value[::-1]
        return int.from_bytes(bytes_value, byteorder='big', signed=True)
    

class BigDecimalData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.BIGDECIMAL

    def get(self) -> Decimal:
        big_decimal = self.data.bigDecimal
        scale = big_decimal.scale
        big_int = big_decimal.unscaledValue
        bytes_value = big_int.value
        if big_int.endianness == Endianness.LITTLE:
            bytes_value = bytes_value[::-1]
        unscaled_value = int.from_bytes(bytes_value, byteorder='big', signed=True)
        return Decimal(unscaled_value).scaleb(-scale)

    def __str__(self) -> str:
        return str(self.get())
    

class ArrayData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.ARRAY

    def get(self) -> List[Data]:
        return [Data.create(element) for element in self.data.array.array]

    def __str__(self) -> str:
        values = ", ".join(f'"{data}"' if data.type() == Type.STRING else str(data) for data in self.get())
        return f"[{values}]"
    

class StructData(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.STRUCT

    def get(self) -> List[Data]:
        return [Data.create(member) for member in self.data.struct.members]

    def __str__(self) -> str:
        values = ", ".join(f'"{data}"' if data.type() == Type.STRING else str(data) for data in self.get())
        return f"({values})"
    

class Uint32Data(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.UINT32

    def get(self) -> int:
        return self.data.uint32
    

class Uint64Data(Data):
    def __init__(self, data: RowData):
        super().__init__(data)

    def type(self) -> Type:
        return Type.UINT64

    def get(self) -> int:
        return self.data.uint64